addToLibrary({
  proxied_js_function__proxy: 'sync',
  proxied_js_function__sig: 'v',
  proxied_js_function: function() {
  	console.log('In proxied_js_function');
  }
});
